@@ -13,7 +13,6 @@ packages <- function() {
       CONST_ALGORITHM_APCLUSTER,
       CONST_ALGORITHM_CLUSTER,
       CONST_ALGORITHM_CLUSTERR,
-      CONST_ALGORITHM_GAMA,
       CONST_ALGORITHM_PVCLUST
     )
   )
@@ -45,7 +44,6 @@ algorithms <- function() {
       CONST_KMEANS_ARMA,
       CONST_KMEANS_RCPP,
       CONST_MINI_KMEANS,
-      CONST_GAMA,
       CONST_PVCLUST
     )
   )
@@ -389,7 +387,6 @@ algorithms_package <- function(packages) {
     algorithms <- c(algorithms, algorithm_apcluster())
     algorithms <- c(algorithms, algorithm_cluster())
     algorithms <- c(algorithms, algorithm_clusterr())
-    algorithms <- c(algorithms, algorithm_gama())
     algorithms <- c(algorithms, algorithm_pvclust())
 
   } else {
@@ -414,10 +411,6 @@ algorithms_package <- function(packages) {
         algorithms <- c(algorithms, algorithm_clusterr())
       }
 
-      if (tolower(packages[iterate]) == CONST_ALGORITHM_GAMA) {
-        algorithms <- c(algorithms, algorithm_gama())
-      }
-
       if (tolower(packages[iterate]) == CONST_ALGORITHM_PVCLUST) {
         algorithms <- c(algorithms, algorithm_pvclust())
       }
@@ -515,10 +508,6 @@ measure_calculate <- function(algorithm) {
       result <- c(result, CONST_MINI_KMEANS)
     }
 
-    if (tolower(algorithm[iterate]) == tolower(CONST_GAMA)) {
-      result <- c(result, CONST_GAMA_EUCLIDEAN)
-    }
-
     if (tolower(algorithm[iterate]) == tolower(CONST_PVCLUST)) {
       result <- c(result, CONST_PVCLUST_EUCLIDEAN)
       result <- c(result, CONST_PVLCUST_CORRELATION)
@@ -549,7 +538,6 @@ measure_package <- function(package) {
     result <- c(result, measure_apcluster())
     result <- c(result, measure_cluster())
     result <- c(result, measure_clusterr())
-    result <- c(result, measure_gama())
     result <- c(result, measure_pvclust())
   } else {
     for (iterate in 1:length(package)) {
@@ -573,10 +561,6 @@ measure_package <- function(package) {
         result <- c(result, measure_clusterr())
       }
 
-      if (tolower(package[iterate]) == CONST_ALGORITHM_GAMA) {
-        result <- c(result, measure_gama())
-      }
-
       if (tolower(package[iterate]) == CONST_ALGORITHM_PVCLUST) {
         result <- c(result, measure_pvclust())
       }
@@ -834,18 +818,6 @@ measure_clusterr <- function() {
 
 }
 
-#' Metrics of the gama algorithm
-#'
-#' @return list with the metrics
-#'
-#' @keywords internal
-#'
-
-measure_gama <- function() {
-  return(c(CONST_GAMA_EUCLIDEAN))
-
-}
-
 #' Metrics of the pvclust algorithm
 #'
 #' @return list with the metrics
@@ -930,17 +902,6 @@ algorithm_clusterr <- function() {
 
 }
 
-#' gama package algorithms
-#'
-#' @return list with the algorithms
-#'
-#' @keywords internal
-#'
-
-algorithm_gama <- function() {
-  return(c(CONST_ALGORITHM_GAMA))
-}
-
 #' pvclust package algorithms
 #'
 #' @return list with the algorithms
