@@ -43,8 +43,6 @@
 
   CONST_MINI_KMEANS <- "mini_kmeans"
 
-  CONST_GAMA <- "gama"
-
   CONST_PVCLUST <- "pvclust"
 
   CONST_ALGORITHM_ADVCLUST <- 'advclust'
@@ -57,8 +55,6 @@
 
   CONST_ALGORITHM_CLUSTERR <- "clusterr"
 
-  CONST_ALGORITHM_GAMA <- "gama"
-
   CONST_ALGORITHM_PVCLUST <- "pvclust"
 
   CONST_PRECISION_METRIC <- "precision"
@@ -165,8 +161,6 @@
 
   CONST_GMM_MANHATTAN <- "gmm_manhattan"
 
-  CONST_GAMA_EUCLIDEAN <- "gama_euclidean"
-
   CONST_PVCLUST_EUCLIDEAN <-"pvclust_euclidean"
 
   CONST_PVLCUST_CORRELATION <- "pvclust_correlation"
